#

##

##

##

##

##

##

##

    		Titaness

    	To give a taste of dry land to
    	those who approach the shores,
    	there is now found
    	the dream and rise of the ocean tides.

    		summary

    This is a module that can reliably
    ascertain the health status of software.

    (It's like a testing kit)

    		install

    [xonsh] pip install Titaness

    		documentation

    [xonsh] Titaness help

    		The status checks of "Titaness".

    			#monitors

    [xonsh] Titaness internal-status

    		These checks are run with pypi "body_scan"
    		"Titaness" is a fork of "body_scan"
    		("body_scan" checks are written with "unittest")

    		Running "Titaness" from a .py
    		from .py

    		Running "Titaness" from the shell
    		shell dictionary

    		Contacts
    		Bryan@Status600.com